<?php

//Publish2 function to download the JSON feed with either cURL or file_get_contents
function p2_download_url($feedlink) {
	
	if (function_exists('curl_init')) {	
		$ch = curl_init();
		$timeout = 0; // set to zero for no timeout
		curl_setopt ($ch, CURLOPT_URL, $feedlink);
		curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
		$ch = curl_init();
		$timeout = 0; // set to zero for no timeout
		curl_setopt ($ch, CURLOPT_URL, $feedlink);
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt ($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
		$data = curl_exec($ch);
		curl_close($ch);
		return $data;
	} else if (function_exists('file_get_contents')) {
		$data = file_get_contents($feedlink);
		return $data;
	}
	
}

//Publish2 function to clean a URL that the user submits
function p2_clean_url($feedlink) {
		
	$testhttp = substr($feedlink, 0, 7);
	if ($testhttp != 'http://')
		$feedlink = 'http://' . $feedlink;
	$testwww = substr($feedlink, 7, 3);
	$feedlink = rtrim($feedlink, 'json');
	$feedlink = rtrim($feedlink, 'JSON');
	$feedlink = rtrim($feedlink, 'rss');
	$feedlink = rtrim($feedlink, 'RSS');
	$testslash = substr($feedlink, -1);
	if ($testslash != '/') {
		$feedlink .= '/';
	}
	return $feedlink;
	
}

//Publish2 function that checks to see whether the URL provides a legit JSON feed or not
function p2_check_url($feedlink) {
	
	if ($feedlink == 'http://' || $feedlink == '') {
		return 'no_url';
	}
	
	$json_url = $feedlink . 'json';
	$json_url .= '?number_of_items=5';
	$contents = p2_download_url($json_url);
	$testcontents = substr($contents, 0, 1);
	if ($testcontents == '{') {
		return true;
	} else {
		return false;		
	}
	
}

//Publish2 function that checks to see whether the required libraries are installed
function p2_check_environment() {
	
	if (!function_exists('json_decode')) {
		$check_environment['json'] = false;
	} else {
		$check_environment['json'] = true;
	}
	
	if (!function_exists('file_get_contents')) {
		$check_environment['file_get_contents'] = false;
	} else {
		$check_environment['file_get_contents'] = true;
	}
	
	if (!function_exists('curl_init')) {
		$check_environment['curl'] = false;
	} else {
		$check_environment['curl'] = true;
	}
	return $check_environment;
	
}

//Publish2 function to display links from a P2 JSON feed based on a variety of settings
function publish2($feedlink = null, $link_count = null, $publication_name = null, $publication_date = null, $journalist_full_name = null, $description = null, $tags = null, $link_format = null, $settings_source = null, $display_list = null) {
	
	global $post;
	$defaults = get_option('publish2_settings');
	
	if ($settings_source != 'widget' && $settings_source != 'page') {
		$options = $defaults;
	}
	
	//Checks to see if there are variables coming into this function.
	if ($feedlink != null) {
		$options['feedlink'] = $feedlink;
	}
	if ($link_count != null) {
		$options['link_count'] = $link_count;
	}
	if ($publication_name != null) {
		$options['publication_name'] = $publication_name;
	}
	if ($publication_date != null) {
		$options['publication_date'] = $publication_date;
	}
	if ($journalist_full_name != null) {
		$options['journalist_full_name'] = $journalist_full_name;
	}
	if ($description != null) {
		$options['description'] = $description;
	}
	if ($tags != null) {
		$options['tags'] = $tags;
	}
	if ($link_format != null) {
		$options['link_format'] = $link_format;
	}
	if ($display_list != null) {
		$options['display_list'] = $display_list;
	}

	$options['feedlink'] = p2_clean_url($options['feedlink']);
	
	// Easter Egg: Make the widget contextual based on which page is loaded.
	// Set any of these to true to make your links contextual on that location.
	// Should degrade gracefully if it doesn't generate a legit feed.
	// Will be supported in coming version of the plugin.
	$dynamic_category = false;
	$dynamic_tag = false;
	$dynamic_author = false;
		
	// If it's a specific page, make the links dynamic to that page
	if (is_category() && $dynamic_category == true) {
		$cat_title = single_cat_title("", false);
		$cat_title = strtolower($cat_title);
		$feedlink_addition = str_replace(' ', '-', $cat_title);
		$json_url = $options['feedlink'] . $feedlink_addition . '/' . 'json';
	} else if (is_tag() && $dynamic_tag == true) {
		$tag_title = single_tag_title("", false);
		$tag_title = strtolower($tag_title);
		$feedlink_addition = str_replace(' ', '-', $tag_title);
		$json_url = $options['feedlink'] . $feedlink_addition . '/' . 'json';
	} else if (is_author() && $dynamic_author == true) {
		$user_id = get_the_author_ID();
		$feedlink = get_usermeta($user_id, 'publish2_url');
		$json_url = $feedlink . 'json';
	} else {
		$json_url = $options['feedlink'] . 'json';
	}

	$json_url .= '?number_of_items=' . $options['link_count'];
	$contents = p2_download_url($json_url);
	
	// Tests to make sure it's a valid JSON string; if not, replace with original URL (w/o tags)
	$testcontents = substr($contents, 0, 1);
	if ($testcontents == '{') {
		$json_data = json_decode($contents, true);
	} else {
		$json_url = $options['feedlink'] . 'json';
		$json_url .= '?number_of_items=' . $options['link_count'];
		$contents = p2_download_url($json_url);
		$json_data = json_decode($contents, true);
	}
	
	//If someone has indicated the order of the links with tokens, then use this option by default
	if ($options['link_format'] != "" && $options['link_format'] != null) {
		
		if ($display_list == true)
			$links .= '<ul>';
		
		foreach ($json_data['items'] as $item) {
			
			$link_format = "";
			
			if ($display_list == true)
				$link_format .= '<li>';
			
			$link_format .= $options['link_format'];
			//Tests to see whether the tokens are included in the string. If so, then it changes them
			if ( stripos($link_format, '%headline%') != false ) {
				$link_format = str_replace('%headline%', '<a href="'.$item['link'].'">'.$item['title'].'</a>', $link_format);
			}
			if ( stripos($link_format, '%source%') != false ) {
				$link_format = str_replace('%source%', $item['publication_name'], $link_format);
			}
			if ( stripos($link_format, '%date%') != false ) {
				$link_format = str_replace('%date%', $item['publication_date'], $link_format);
			}
			if ( stripos($link_format, '%journalist%') != false ) {
				$link_format = str_replace('%journalist%', '<a href="'.$item['journalist_profile'].'">'.$item['journalist_full_name'].'</a>', $link_format);
			}
			if ( stripos($link_format, '%comment%') != false ) {
				$link_format = str_replace('%comment%', $item['description'], $link_format);
			}
			if ( stripos($link_format, '%tags%') != false && is_array($item['tags'])) {
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_link"';
					$tag_list .= '>' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$link_format = str_replace('%tags%', $tag_list, $link_format);
			}

			$links .= $link_format;
		
			if ($display_list == true) {
				$links .= '</li>';
			}
				
		}
		
		if ($display_list == true) {
			$links .= '</ul>';
		}
		
	} else if (($settings_source == 'widget' && $options['link_format'] == "") || $display_list == true) {
		
		$links .= '<ul>';
		
		foreach ($json_data['items'] as $item) {
			$links .= '<li>';
			$links .= '<a href="'. $item['link'] . '" class="publish2_story_headline">' . $item['title'] . '</a>';

			//whether to show the pub name, date, both or none. Includes a filter if the user didn't save publication_name or publication_date
			if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
				$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . ' | ' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) == 0)) {
				$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . '</div>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) == 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
				$links .= '<div>' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == false)) {
				$links .= '<div>' . '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . '</div>';
			} else if (($options['publication_date'] == true && strlen($item['publication_date']) != 0) && ($options['publication_name'] == false)) {
				$links .= '<div>' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>' . '</div>';
			}

			//whether to show comments or not. Includes to drop the whole graf if there isn't a comment
			if (($options['description'] == true && strlen($item['description']) != 0) && $options['journalist_full_name'] == true) {
				$links .= '<div>' . '<a href="'. $item['journalist_profile'] . '" class="publish2_journalist_profile">' . $item['journalist_full_name'] . '</a>' . ' says: ';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>' . '</div>';
			}
			else if ($options['description'] == true) {
				$links .= '<div>' . '<span class="publish2_story_description">' . $item['description'] . '</span>' . '</div>';
			}

			//option whether to display the tags or not
			if ($options['tags'] == true && is_array($item['tags'])) {
				$links .= '<div>' . 'Tags: ';
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_story_tags">' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$links .= $tag_list;
				$links .= '</div>';		
			}
			
			$links .= '</li>';
		}
		
		$links .= '</ul>';

	} else {
		
		if ($display_list == true)
			$links .= '<ul>';

		foreach ($json_data['items'] as $item) {

			if ($display_list == true)
				$links .= '<li>';

			if ($settings_source == 'page') {
				$links .= '<h3>';
			} else {
				$links .= '<h4>';
			}
			
			$links .= '<a href="'. $item['link'] . '" class="publish2_story_headline">' . $item['title'] . '</a>';
				
			if ($settings_source == 'page') {
				$links .= '</h3>';
			} else {
				$links .= '</h4>';
			}

			//whether to show the pub name, date, both or none. Includes a filter if the user didn't save publication_name or publication_date
			if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>' . ' | ' . '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
				$links .= '</p>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == true && strlen($item['publication_date']) == 0)) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>';
				$links .= '</p>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) == 0) && ($options['publication_date'] == true && strlen($item['publication_date']) != 0)) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
				$links .= '</p>';
			} else if (($options['publication_name'] == true && strlen($item['publication_name']) != 0) && ($options['publication_date'] == false)) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_publication_name">' . $item['publication_name'] . '</span>';
				$links .= '</p>';
			} else if (($options['publication_date'] == true && strlen($item['publication_date']) != 0) && ($options['publication_name'] == false)) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_publication_date">' . $item['publication_date'] . '</span>';
				$links .= '</p>';
			}

				//whether to show comments or not. Includes to drop the whole graf if there isn't a comment
			if (($options['description'] == true && strlen($item['description']) != 0) && $options['journalist_full_name'] == true) {
				$links .= '<p>';
				$links .= '<a href="'. $item['journalist_profile'] . '" class="publish2_journalist_profile">' . $item['journalist_full_name'] . '</a>' . ' says: ';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>';
				$links .= '</p>';
			} else if ($options['description'] == true) {
				$links .= '<p>';
				$links .= '<span class="publish2_story_description">' . $item['description'] . '</span>';
				$links .= '</p>';
			}

			//option whether to display the tags or not
			if ($options['tags'] == true && is_array($item['tags'])) {
				$links .= '<p>';
				$links .= 'Tags: ';
				$tag_list = ''; //dislaying tags 
				foreach ($item['tags'][0] as $tag) {
					$tag_list .= '<a href="'. $tag['link'] . '" class="publish2_story_tags">' . $tag['name'] . '</a>' . ", ";
				}
				$tag_list = rtrim($tag_list, ', ');
				$links .= $tag_list;
				$links .= '</p>';		
			}

			if ($display_list == true)
				$links .= '</li>';

		}

		if ($display_list == true)
			$links .= '</ul>';

	}
	
	if ($settings_source == 'page' || $settings_source == 'filter') {
		return $links;
	} else {
		echo $links;
	}
	
}

?>